==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Aplikácia</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;plochu</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>&amp;Všetky plochy</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>Plocha &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na aktuálnu plochu</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximalizovať</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Maximalizovať zvisle</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Maximalizovať vodorovne</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Obnoviť</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimalizovať</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Zrolovať nahor</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Zrolovať dolu</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>&amp;Vrstva</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Vždy &amp;navrchu</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normálne</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Vždy na&amp;spodku</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvoriť</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Nastavenia správcu úloh prostredia Razor</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Obsah zoznamu okien</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>Zobraziť okná z aktuálnej plochy</translation>
    </message>
    <message>
        <source>wlcB</source>
        <translation>wlcB</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Zobraziť okná z každej plochy</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Vzhľad zoznamu okien</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Štýl tlačidiel</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Maximálna šírka tlačidla</translation>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Ikona a text</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Iba ikona</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Iba text</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_sk_SK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Aplikácia</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;plochu</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>&amp;Všetky plochy</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>Plocha &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na aktuálnu plochu</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximalizovať</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Maximalizovať zvisle</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Maximalizovať vodorovne</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Obnoviť</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimalizovať</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Zrolovať nahor</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Zrolovať dolu</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>&amp;Vrstva</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Vždy &amp;navrchu</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normálne</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Vždy na&amp;spodku</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvoriť</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Nastavenia správcu úloh prostredia Razor</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Obsah zoznamu okien</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>Zobraziť okná z aktuálnej plochy</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Zobraziť okná z každej plochy</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Vzhľad zoznamu okien</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Štýl tlačidiel</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Maximálna šírka tlačidla</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Ikona a text</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Iba ikona</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Iba text</translation>
    </message>
</context>
</TS>
